@@ -405,17 +405,20 @@ class dyagram:
                             f"{routing_protocol} Neighbor {diff_resp[k][diff]['new_value']}")
 
                 elif category == "layer2":
+                    print("LAYER2 CHANGE DETECTED")
                     if diff_type != "changed":
                         device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
                             f"LLDP Neighbor {diff_resp[k][diff]['hostname']} (Chassis ID: {diff_resp[k][diff]['chassis_id']})")
                     else:
+                        print("diff type == changed")
                         resp = re.search("\['neighbors'\]\[(\d+)\]\['(.*)'\]", diff)
                         neigh_elem = int(resp.group(1))
                         neigh_property = resp.group(2)
+                        print("before append")
                         device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
                             f"LLDP Neighbor {s['devices'][device_elem][category]['neighbors'][neigh_elem]['hostname']}: {neigh_property}: "
                             f"NEW VALUE: {diff_resp[k][diff]['new_value']}, OLD VALUE: {diff_resp[k][diff]['old_value']}")
-
+                        print("after append")
                 elif category == "routes":
 
                     if diff_type != "changed":
